# NOT RUN {
#If it is necessary to indicate any existing configuration key, do it through:
#bdpar.Options$set(key, value)
#If the key is not initialized, do it through:
#bdpar.Options$add(key, value)
#Folder with the files to preprocess
path <- system.file(file.path("example"),
package = "bdpar")
#Object which decides how creates the instances
extractors <- ExtractorFactory$new()
#Object which indicates the pipes' flow
pipeline <- DefaultPipeline$new()
objectBdpar <- Bdpar$new()
#Starting file preprocessing...
objectBdpar$execute(path = path,
extractors = extractors,
pipeline = pipeline)
# }
Run the code above in your browser using DataLab