This DefaultPipeline class inherits from the
GenericPipeline class. Includes the execute method which
provides a default pipelining implementation.
DefaultPipelineDefaultPipeline$new()
This class inherits from GenericPipeline and implements the
execute abstract function.
execute: function where is implemented the flow of the pipes.
get: gets a list with containinig the set of pipes of the pipeline,
Usage:
get()
Value: the set of pipes containing the pipeline.
The default flow is:
instance %>|%TargetAssigningPipe$new() %>|%
StoreFileExtPipe$new() %>|%
GuessDatePipe$new() %>|%
File2Pipe$new() %>|%
MeasureLengthPipe$new(propertyName = "length_before_cleaning_text") %>|%
FindUserNamePipe$new() %>|%
FindHashtagPipe$new() %>|%
FindUrlPipe$new() %>|%
FindEmoticonPipe$new() %>|%
FindEmojiPipe$new() %>|%
GuessLanguagePipe$new() %>|%
ContractionPipe$new() %>|%
AbbreviationPipe$new() %>|%
SlangPipe$new() %>|%
ToLowerCasePipe$new() %>|%
InterjectionPipe$new() %>|%
StopWordPipe$new() %>|%
MeasureLengthPipe$new(propertyName = "length_after_cleaning_text") %>|%
TeeCSVPipe$new()
Instance, DynamicPipeline,
GenericPipeline, GenericPipe,
%>|%