Learn R Programming

bdpar (version 2.0.0)

DynamicPipeline: Class implementing a dynamic pipelining proccess.

Description

This DynamicPipeline class inherits from the GenericPipeline class. Includes the execute method which provides a dynamic pipelining implementation.

Usage

DynamicPipeline

Arguments

Constructor

DynamicPipeline$new(pipeline = NULL)

Inherit

This class inherits from GenericPipeline and implements the execute abstract function.

Methods

  • add: adds a pipe or a pipe list to the pipeline

    • Usage: add(pipe, pos)

    • Arguments:

      • pipe: (GenericPipe) pipe objects or a list of pipes to add

      • pos: (numeric) the value of the pos to add. If it is NULL, pipe is appended to the pipeline

  • removeByPos: removes pipes by the position on the pipeline

    • Usage: removeByPos(pos)

    • Arguments:

      • pos: (numeric) the pipe positions to remove.

  • removeByPipe: removes pipes by its name on the pipeline

    • Usage: removeByPipe(pipe.name)

    • Arguments:

      • pipe.name: (character) the pipe name to remove.

  • removeAll: removes all pipes included on pipeline

    • Usage: removeAll()

  • execute: function where is implemented the flow of the pipes.

    • Usage: execute(instance)

    • Value: the preprocessed Instance.

    • Arguments:

      • instance: (Instance) the Instance that is going to be processed.

  • get: gets a list with containinig the set of pipes of the pipeline,

    • Usage: get()

    • Value: the set of pipes containing the pipeline.

See Also

Instance, DefaultPipeline, GenericPipeline, GenericPipe, %>|%