This class inherits from the Instance class and
implements the functions of extracting the text and the date from an eml type file.
ExtractorEmlExtractorEml$new(path)
Arguments:
path: (character) path of the eml type file.
PartSelectedOnMPAlternative: (character) configuration to read the eml files. If it is NULL, checks if is defined in the "extractorEML.mpaPartSelected" field of bdpar.Options variable.
This class inherits from Instance and implements the
obtainSource and obtainDate abstracts functions.
obtainDate: obtains the date of the eml file. Calls the function read_emails and obtains the date of the file indicated in the path and then transforms it into the generic date format, that is "%a %b %d %H:%M:%S %Z %Y" (Example: "Thu May 02 06:52:36 UTC 2013").
Usage:
obtainDate()
obtainSource: obtains the source of the eml file. Calls the function read_emails and obtains the source of the file indicated in the path. In addition, it initializes the data with the initial source.
Usage:
obtainSource()
getPartSelectedOnMPAlternative:
gets of PartSelectedOnMPAlternative variable.
Usage:
getPartSelectedOnMPAlternative()
Value:
value of PartSelectedOnMPAlternative variable.
setPartSelectedOnMPAlternative:
sets of PartSelectedOnMPAlternative variable.
Usage:
setPartSelectedOnMPAlternative(PartSelectedOnMPAlternative)
Arguments:
PartSelectedOnMPAlternative
(character) the new value of PartSelectedOnMPAlternative variable.
PartSelectedOnMPAlternative: (character) configuration to read the eml files. Indicates whether the text/plain part or the text/html part is read in multipart emails.
The way to indicate which part to choose in the email, when is a multipart email, is through the "extractorEML.mpaPartSelected" field of bdpar.Options variable.
bdpar.Options, ExtractorSms,
ExtractorTwtid, ExtractorYtbid,
Instance