Abstract super class to establish the flow of Pipes.
GenericPipelineGenericPipeline$new()
execute: function where is implemented the flow of the pipes.
get: gets a list with containinig the set of pipes of the pipeline,
Usage:
get()
Value: the set of pipes containing the pipeline.
DefaultPipeline, DynamicPipeline,
Instance, GenericPipe, %>|%