This class is responsible of obtain the length of thedata
field of each Instance. Creates the length property
which indicates the length of the text. The property's name is customize
throught the class constructor.
MeasureLengthPipe
MeasureLengthPipe$new(propertyName = "length",
alwaysBeforeDeps = list(),
notAfterDeps = list(),
nchar_conf = TRUE)
Arguments:
propertyName: (character) name of the property associated with the Pipe.
alwaysBeforeDeps: (list) the dependences alwaysBefore (Pipes that must be executed before this one).
notAfterDeps: (list) the dependences notAfter (Pipes that cannot be executed after this one).
nchar_conf (logical) indicates if the Pipe uses nchar or object.size.
This class inherits from GenericPipe and implements the
pipe abstract function.
pipe:
preprocesses the Instance to obtain the length of data.
getLength: obtains the length of the data.
Usage:
getLength(data, nchar_conf = TRUE)
Value:
the Instance with the modifications that have occurred in the Pipe.
Arguments:
data: (character) text to preproccess.
nchar_conf: (logical) indicates if the Pipe uses nchar or object.size.
nchar_conf: (logical) indicates if the Pipe uses nchar or object.size.
AbbreviationPipe, ContractionPipe,
File2Pipe, FindEmojiPipe,
FindEmoticonPipe, FindHashtagPipe,
FindUrlPipe, FindUserNamePipe,
GuessDatePipe, GuessLanguagePipe,
Instance, InterjectionPipe,
GenericPipe, ResourceHandler,
SlangPipe, StopWordPipe,
StoreFileExtPipe, TargetAssigningPipe,
TeeCSVPipe, ToLowerCasePipe