Learn R Programming

bdpar (version 2.0.0)

ToLowerCasePipe: Class to convert the data field of an Instance to lower case

Description

Class to convert the data field of an Instance to lower case.

Usage

ToLowerCasePipe

Arguments

Constructor

ToLowerCasePipe$new(propertyName = "",
                    alwaysBeforeDeps = list(),
                    notAfterDeps = list())
  • Arguments:

    • propertyName: (character) name of the property associated with the Pipe.

    • alwaysBeforeDeps: (list) the dependences alwaysBefore (Pipes that must be executed before this one).

    • notAfterDeps: (list) the dependences notAfter (Pipes that cannot be executed after this one).

Inherit

This class inherits from GenericPipe and implements the pipe abstract function.

Methods

  • pipe: preprocesses the Instance to convert the data to lower case.

    • Usage: pipe(instance)

    • Value: the Instance with the modifications that have occurred in the Pipe.

    • Arguments:

      • instance: (Instance) Instance to preproccess.

  • toLowerCase: converts the data to lower case.

    • Usage: toLowerCase(data)

    • Value: data in lower case.

    • Arguments:

      • data: (character) text to preproccess.

See Also

AbbreviationPipe, ContractionPipe, File2Pipe, FindEmojiPipe, FindEmoticonPipe, FindHashtagPipe, FindUrlPipe, FindUserNamePipe, GuessDatePipe, GuessLanguagePipe, Instance, InterjectionPipe, MeasureLengthPipe, GenericPipe, ResourceHandler, SlangPipe, StopWordPipe, StoreFileExtPipe, TargetAssigningPipe, TeeCSVPipe