This class provides the necessary methods to manage a list of keys or options used along the pipe flow, both those provided by the default library and those implemented by the user.
bdpar.Optionsget: obtains a specific option.
Usage:
get(key)
Value: the value of the specific option.
Arguments:
key: (character) the name of the option to obtain.
add: adds a option to the list of options
Usage:
add(key, value)
Arguments:
key: (character) the name of the new option.
propertyName: (Object) the value of the new option.
set: modifies the value of the one option.
Usage:
set(key, value)
Arguments:
key: (character) the name of the new option.
propertyName: (Object) the value of the new option.
remove: removes a specific option.
Usage:
remove(key)
Arguments:
key: (character) the name of the option to remove.
getAll: gets the list of options.
Usage:
getAll()
Value: Value of options.
remove: resets the option list to the initial state.
Usage:
reset()
isSpecificOption: checks for the existence of an specific option.
Usage:
isSpecificProperty(key)
Value: A boolean results according to the existence of the specific option in the list of options
Arguments:
key: (character) the key of the option to check.
By default, the application initializes the object named bdpar.Options
of type BdparOptions which is in charge of initializing the
options used in the defined pipes.
The default fields on bdpar.Options are initialized, if needed, as shown bellow:
[eml]
- bdpar.Options$set("extractorEML.mpaPartSelected", <<PartSelectedOnMPAlternative>>)
[resources]
- bdpar.Options$set("resources.abbreviations.path", <<abbreviation.path>>)
- bdpar.Options$set("resources.contractions.path", <<contractions.path>>)
- bdpar.Options$set("resources.interjections.path", <<interjections.path>>)
- bdpar.Options$set("resources.slangs.path", <<slangs.path>>)
- bdpar.Options$set("resources.stopwords.path", <<stopwords.path>>)
[twitter]
- bdpar.Options$set("twitter.consumer.key", <<consumer_key>>)
- bdpar.Options$set("twitter.consumer.secret", <<consumer_secret>>)
- bdpar.Options$set("twitter.access.token", <<access_token>>)
- bdpar.Options$set("twitter.access.token.secret", <<access_token_secret>>)
- bdpar.Options$set("cache.twitter.path", <<cache.path>>)
[teeCSVPipe]
- bdpar.Options$set("teeCSVPipe.output.path", <<outputh.path>>)
[youtube]
- bdpar.Options$set("youtube.app.id", <<app_id>>)
- bdpar.Options$set("youtube.app.password", <<app_password>>)
- bdpar.Options$set("cache.youtube.path", <<cache.path>>)
AbbreviationPipe, Connections,
ContractionPipe, ExtractorEml,
ExtractorTwtid, ExtractorYtbid,
GuessLanguagePipe, SlangPipe,
StopWordPipe, TeeCSVPipe