Defines a customized fordward pipe operator extending the
features of classical %>%. Concretely %>|% is able to stop the pipelining
process whenever an Instance has been invalidated. This issue,
avoids executing the whole pipelining proccess for the invalidated
Instance and therefore reduce the time and resources used to
complete the whole proccess.
lhs %>|% rhsan Instance object.
a function call using the bdpar semantics.
The Instance modified by the methods it has traversed.
This is the %>% operator of the modified magrittr library to both
(i) to stop the flow when the Instance is invalid and (ii)
automatically call the pipe function of the R6 objects passing
through it and (iii) check the dependencies of the Instance.
The usage structure would be as shown below:
instance %>|%pipeObject$new() %>|%
pipeObject$new(<<argument1>>, <<argument2>, ...) %>|%
pipeObject$new()